Struct fasten::io::seq::Seq [−][src]
pub struct Seq {
pub id: String,
pub seq: String,
pub qual: String,
pub pairid: String,
pub thresholds: HashMap<String, f32>,
}Expand description
A sequence struct that contains the ID, sequence, and quality cigar line
Fields
id: Stringseq: Stringqual: Stringpairid: Stringthresholds: HashMap<String, f32>Trait Implementations
Create a sequence object from a string. TODO make it more like the careful method than quick.
Read an identifier and return a cleaned version, e.g., removing @ in a fastq identifier.
Alter any ambiguity site with a quality=0
Reports bool whether the read passes thresholds.